==> jupyter_app_launcher-0.1.4.tar.gz: jupyter_app_launcher-0.1.4/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.4

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.3...905393074b86d038ec2d82b5ade81158a2f7d44f))

### Enhancements made

- Add notebook gridstack document [#11](https://github.com/trungleduc/jupyter_app_launcher/pull/11) ([@trungleduc](https://github.com/trungleduc))
- Remove voila-gridstack from dependencies list  [#10](https://github.com/trungleduc/jupyter_app_launcher/pull/10) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- Add notebook gridstack document [#11](https://github.com/trungleduc/jupyter_app_launcher/pull/11) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-10-08&to=2022-10-10&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-10-08..2022-10-10&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-10-08..2022-10-10&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.3

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.2...6dff12cf495574b1881ba93599d94884054cdff8))

### Enhancements made

- Improve `notebook-grid` dashboard. [#8](https://github.com/trungleduc/jupyter_app_launcher/pull/8) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- Add stock dashboard example [#6](https://github.com/trungleduc/jupyter_app_launcher/pull/6) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-18&to=2022-10-08&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-09-18..2022-10-08&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-18..2022-10-08&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.1...126be69e271b681c370713ecb8ac87e05eb323c2))

### Merged PRs

- Remove `Literal` typing [#4](https://github.com/trungleduc/jupyter_app_launcher/pull/4) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-17&to=2022-09-18&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-17..2022-09-18&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.0.0...b20812f7fdcc2a880fd1db9c20a6b12c6824b085))

### Merged PRs

- Add lite workflow [#2](https://github.com/trungleduc/jupyter_app_launcher/pull/2) ([@trungleduc](https://github.com/trungleduc))
- Add documentation [#1](https://github.com/trungleduc/jupyter_app_launcher/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-04&to=2022-09-17&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-09-04..2022-09-17&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-04..2022-09-17&type=Issues)

==> jupyter_app_launcher-0.1.5.tar.gz: jupyter_app_launcher-0.1.5/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.5

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.4...7040059d7c75904332f7d08a1f1e374e2ef3c117))

### Merged PRs

- Fix missing session of grid app [#14](https://github.com/trungleduc/jupyter_app_launcher/pull/14) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-10-10&to=2022-10-13&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-10-10..2022-10-13&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.4

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.3...905393074b86d038ec2d82b5ade81158a2f7d44f))

### Enhancements made

- Add notebook gridstack document [#11](https://github.com/trungleduc/jupyter_app_launcher/pull/11) ([@trungleduc](https://github.com/trungleduc))
- Remove voila-gridstack from dependencies list [#10](https://github.com/trungleduc/jupyter_app_launcher/pull/10) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- Add notebook gridstack document [#11](https://github.com/trungleduc/jupyter_app_launcher/pull/11) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-10-08&to=2022-10-10&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-10-08..2022-10-10&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-10-08..2022-10-10&type=Issues)

## 0.1.3

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.2...6dff12cf495574b1881ba93599d94884054cdff8))

### Enhancements made

- Improve `notebook-grid` dashboard. [#8](https://github.com/trungleduc/jupyter_app_launcher/pull/8) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- Add stock dashboard example [#6](https://github.com/trungleduc/jupyter_app_launcher/pull/6) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-18&to=2022-10-08&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-09-18..2022-10-08&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-18..2022-10-08&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.1.1...126be69e271b681c370713ecb8ac87e05eb323c2))

### Merged PRs

- Remove `Literal` typing [#4](https://github.com/trungleduc/jupyter_app_launcher/pull/4) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-17&to=2022-09-18&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-17..2022-09-18&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/trungleduc/jupyter_app_launcher/compare/v0.0.0...b20812f7fdcc2a880fd1db9c20a6b12c6824b085))

### Merged PRs

- Add lite workflow [#2](https://github.com/trungleduc/jupyter_app_launcher/pull/2) ([@trungleduc](https://github.com/trungleduc))
- Add documentation [#1](https://github.com/trungleduc/jupyter_app_launcher/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyter_app_launcher/graphs/contributors?from=2022-09-04&to=2022-09-17&type=c))

[@github-actions](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Agithub-actions+updated%3A2022-09-04..2022-09-17&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyter_app_launcher+involves%3Atrungleduc+updated%3A2022-09-04..2022-09-17&type=Issues)
